# Security Policy

## Supported Versions

| Version | Supported |
|---------|-----------|
| 1.x.x   | Yes       |

## Reporting a Vulnerability

Do not open a public GitHub issue for security vulnerabilities.

Email: hello@razi.sh

Include:
- Description of the vulnerability
- Steps to reproduce
- Potential impact
- Suggested fix if you have one

We will respond within 72 hours and aim to release a patch within 14 days of confirmed vulnerabilities.
